@@ -26,10 +26,7 @@ usage ="""mm2xhtml Usage:
 
 def parseHEADER(inText):
     m = HeaderParser().parsestr(inText)
-    headers = {}
-    for k, v in m.items():
-        headers[k] = v
-    return (headers, m.get_payload())
+    return (m.items(), m.get_payload())
 
 def mm2xhtml_file(inFile,outFile,type='body',chapter=-1):
     inString = inFile.read()
